| Title: | Report Templates and Helper Functions for Applied Epidemiology |
|---|---|
| Description: | A meta-package that loads the complete sitrep ecosystem for applied epidemiology analysis. This package provides report templates and automatically loads companion packages, including 'epitabulate' (for epidemiological tables), 'epidict' (for data dictionaries), 'epikit' (for epidemiological utilities), and 'apyramid' (for age-sex pyramids). Simply load 'sitrep' to access all functions from the ecosystem. |
| Authors: | Alexander Spina [aut, cre] (ORCID: <https://orcid.org/0000-0001-8425-1867>), Zhian N. Kamvar [aut] (ORCID: <https://orcid.org/0000-0003-1458-7108>), Dirk Schumacher [aut], Kate Doyle [aut], Chris Jarvis [aut], Lukas Richter [aut], Paula Blomquist [aut], Annick Lenglet [ctb], Neale Batra [ctb], Applied Epi Incorporated [cph], Medecins Sans Frontieres Operational Centre Amsterdam [fnd] |
| Maintainer: | Alexander Spina <[email protected]> |
| License: | GPL-3 |
| Version: | 0.4.1 |
| Built: | 2026-05-26 08:49:40 UTC |
| Source: | https://github.com/r4epi/sitrep |
Display the available sitrep templates
available_sitrep_templates(categorise = FALSE, ...)available_sitrep_templates(categorise = FALSE, ...)
categorise |
if |
... |
options to pass on to dir |
a vector of available templates in the sitrep package
available_sitrep_templates(categorise = TRUE) available_sitrep_templates(categorise = TRUE, full.names = TRUE)available_sitrep_templates(categorise = TRUE) available_sitrep_templates(categorise = TRUE, full.names = TRUE)
Run the templates found in the sitrep package.
check_sitrep_templates( templates = available_sitrep_templates(), path = tempdir(), quiet = FALSE, progress = FALSE, mustwork = FALSE, output_format = NULL, clean = TRUE )check_sitrep_templates( templates = available_sitrep_templates(), path = tempdir(), quiet = FALSE, progress = FALSE, mustwork = FALSE, output_format = NULL, clean = TRUE )
templates |
a vector of templates to create and render |
path |
a directory in which to store the templates |
quiet |
if |
progress |
if |
mustwork |
if |
output_format |
a character defining the output formats to use for the
template files. Defaults to the output_format defined in the templates
(which is |
clean |
if |
the path where the templates were built.
check_sitrep_templates("mortality")check_sitrep_templates("mortality")
Checks if all packages needed for the sitrep ecosystem are installed and loads properly. Useful for verifying offline readiness.
sitrep_check_deps(quiet = FALSE)sitrep_check_deps(quiet = FALSE)
quiet |
Should output be suppressed? Default is FALSE |
Named logical vector indicating which packages are available. Names are package names, values are TRUE if available, FALSE otherwise.
# Check what's missing before going offline sitrep_check_deps()# Check what's missing before going offline sitrep_check_deps()
This function identifies any naming conflicts between functions in the sitrep ecosystem packages.
sitrep_conflicts()sitrep_conflicts()
NULL (invisibly). Prints messages about conflicts to console.
Shows all available functions across the sitrep ecosystem packages.
sitrep_functions(pattern = NULL)sitrep_functions(pattern = NULL)
pattern |
Optional regex pattern to filter function names |
A data frame with columns 'package' and 'function_name', sorted by package and function name.
This function provides code to install all packages needed for the complete sitrep ecosystem, ensuring you have everything needed for working without internet connection.
sitrep_install_deps( upgrade = "ask", dependencies = TRUE, repos = getOption("repos"), quiet = FALSE, force = FALSE )sitrep_install_deps( upgrade = "ask", dependencies = TRUE, repos = getOption("repos"), quiet = FALSE, force = FALSE )
upgrade |
Should packages be upgraded? Options: "ask", "always", "never". Default is "ask" |
dependencies |
Should dependencies be installed? Default is TRUE |
repos |
Repository to use. Default uses getOption("repos") |
quiet |
Should installation be quiet? Default is FALSE |
force |
Should installation proceed without prompts? Default is FALSE |
This function reads the sitrep DESCRIPTION file and provides code to install all packages listed in Depends, Imports, and Suggests fields. This ensures complete functionality in offline environments.
Character vector of all dependency package names (invisibly).
# Install everything for offline field work (with prompts) sitrep_install_deps() # Install without prompts sitrep_install_deps(force = TRUE) # Install quietly without prompts or upgrades sitrep_install_deps(upgrade = "never", quiet = TRUE, force = TRUE)# Install everything for offline field work (with prompts) sitrep_install_deps() # Install without prompts sitrep_install_deps(force = TRUE) # Install quietly without prompts or upgrades sitrep_install_deps(upgrade = "never", quiet = TRUE, force = TRUE)